Authors
*******

Main developer
==============

Hippolyte Verdier <hverdier@pasteur.fr>

Team
=====

`Decision and Bayesian computation lab <https://research.pasteur.fr/en/team/decision-and-bayesian-computation/>`_, Institut Pasteur, Paris